@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef KSMSERVER_P_H
-#define KSMSERVER_P_H
+#pragma once
 
 // Self
 #include "KSMServer.h"
@@ -47,5 +46,3 @@ private:
 
     KSMServer *const q;
 };
-
-#endif // KSMSERVER_P_H
